<?xml version='1.0'?>

<!--
    
    UNIDOC.XSL - Stylesheet for Unicorn documentation

    Copyright (C) 2000, Unicorn Enterprises SA
    All rights reserved

    Version:  1.00.00 (alpha)
    Date:     05/17/2000
    Author:   A.Gokhberg

-->


<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                version="1.0"
                result-ns="http://www.w3.org/TR/REC-html40">

  <xsl:output method="html"
              version="4.0"
              doctype-public="-//W3C//DTD HTML 4.0 Transitional//EN"
              doctype-system="http://www.w3.org/TR/REC-html40/loose.dtd"
              encoding="ISO-8859-1"/>

  <xsl:strip-space elements="*"/>


<!--

    Global variables 
    
    (MAY BE CUSTOMIZED)

-->


<!-- Output original flag -->

<!--

    Set the following variable to "true" is output of the
    original text is required.

-->

  <xsl:variable name="original" select="false"/>


<!-- Left and right quotation marks -->

  <xsl:variable name="ldquo">&#8220;</xsl:variable>
  <xsl:variable name="rdquo">&#8221;</xsl:variable>


<!-- Note label -->

  <xsl:variable name="note-label">
    <SPAN CLASS="note-label">NOTE. </SPAN>
  </xsl:variable>


<!-- Pointer labels -->

  <xsl:variable name="ptr-label">
    <SPAN CLASS="ptr-label">(click here)</SPAN>
  </xsl:variable>

  <xsl:variable name="xptr-label">
    <SPAN CLASS="xptr-label">(click here)</SPAN>
  </xsl:variable>


<!-- Markers for editorial intervantions -->

  <xsl:variable name="sic-after">[sic]</xsl:variable>
  

<!-- Markers for omissions, deletions and additions -->

  <xsl:variable name="add-before">[</xsl:variable>
  <xsl:variable name="add-after">]</xsl:variable>


<!-- Figure label -->

  <xsl:variable name="figure-label">
    <SPAN CLASS="figure-label">[Figure]</SPAN>
  </xsl:variable>


<!-- Prefix for continued lines -->

  <xsl:variable name="continued-line">
    <SPAN>&#160;</SPAN>
  </xsl:variable>


<!--

    Key declarations

-->

<!-- Index of simple cross-references -->

<!--

    Instead of using keys, it is possible to generate an A anchor
    element for each source element that has an ID attribute.
    However, keys are cool and demonstrate some advanced XSLT
    features, so we are using them in this implementation.

-->

  <xsl:key name="ref" 
           match="ref[@target]|ptr[@target]" 
           use="@target"/>


<!--

    Document Root

-->

  <xsl:template match="/">
    <HTML>
      <HEAD>
        <TITLE>
          <xsl:choose>
            <xsl:when test="TEI.2/teiHeader/fileDesc/titleStmt/title">
              <xsl:apply-templates 
                  select="TEI.2/teiHeader/fileDesc/titleStmt/title"/>
            </xsl:when>
            <xsl:otherwise>
              no title
            </xsl:otherwise>
          </xsl:choose>
        </TITLE>
        <xsl:call-template name="style"/>
      </HEAD>
      <BODY>
        <xsl:apply-templates/>
      </BODY>
    </HTML>
  </xsl:template>


<!--

    [TEI Lite] 3. The Structure of TEI Text

    Only unitary texts are supported.

-->

  <xsl:template match="TEI.2">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="teiHeader"/>    <!-- skipped -->

  <xsl:template match="text">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'text'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="front">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'front'"/>
    </xsl:call-template>
    <HR CLASS="front"/>
  </xsl:template>

  <xsl:template match="body">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'body'"/>
    </xsl:call-template>
    <HR CLASS="body"/>
  </xsl:template>

  <xsl:template match="back">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'back'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="back/head">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'back-head'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 4.1 Text Division Elements

-->

  <xsl:template match="p">
    <P>
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </P>
  </xsl:template>

  <xsl:template match="div|div1|div2|div3|div4|div5|div6|div7">
    <DIV>
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </DIV>
  </xsl:template>


<!--

    [TEI Lite] 4.2 Headings and Closings

-->

  <xsl:template match="div/head">
    <xsl:call-template name="head">
      <xsl:with-param name="level" select="count(ancestor::div)"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="div1/head">
    <xsl:call-template name="head">
      <xsl:with-param name="level" select="1"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="div2/head">
    <xsl:call-template name="head">
      <xsl:with-param name="level" select="2"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="div3/head">
    <xsl:call-template name="head">
      <xsl:with-param name="level" select="3"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="div4/head">
    <xsl:call-template name="head">
      <xsl:with-param name="level" select="4"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="div5/head">
    <xsl:call-template name="head">
      <xsl:with-param name="level" select="5"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="div6/head">
    <xsl:call-template name="head">
      <xsl:with-param name="level" select="6"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="div7/head">
    <xsl:call-template name="head">
      <xsl:with-param name="level" select="7"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="head">
    <xsl:param name="level" select="6"/>
    <xsl:choose>
      <xsl:when test="$level=1">
        <H1>
          <xsl:call-template name="common-attributes"/>
          <xsl:call-template name="anchor"/>
          <xsl:call-template name="div-number"/>
          <xsl:apply-templates/>
        </H1>
      </xsl:when>
      <xsl:when test="$level=2">
        <H2>
          <xsl:call-template name="common-attributes"/>
          <xsl:call-template name="anchor"/>
          <xsl:call-template name="div-number"/>
          <xsl:apply-templates/>
        </H2>
      </xsl:when>
      <xsl:when test="$level=3">
        <H3>
          <xsl:call-template name="common-attributes"/>
          <xsl:call-template name="anchor"/>
          <xsl:call-template name="div-number"/>
          <xsl:apply-templates/>
        </H3>
      </xsl:when>
      <xsl:when test="$level=4">
        <H4>
          <xsl:call-template name="common-attributes"/>
          <xsl:call-template name="anchor"/>
          <xsl:call-template name="div-number"/>
          <xsl:apply-templates/>
        </H4>
      </xsl:when>
      <xsl:when test="$level=5">
        <H5>
          <xsl:call-template name="common-attributes"/>
          <xsl:call-template name="anchor"/>
          <xsl:call-template name="div-number"/>
          <xsl:apply-templates/>
        </H5>
      </xsl:when>
      <xsl:when test="$level=6">
        <H6>
          <xsl:call-template name="common-attributes"/>
          <xsl:call-template name="anchor"/>
          <xsl:call-template name="div-number"/>
          <xsl:apply-templates/>
        </H6>
      </xsl:when>
      <xsl:otherwise>
        <DIV CLASS="head">
          <xsl:call-template name="common-attributes"/>
          <xsl:call-template name="anchor"/>
          <xsl:call-template name="div-number"/>
          <xsl:apply-templates/>
        </DIV>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="trailer">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'trailer'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 4.3 Prose, Verse and Drama

-->

  <xsl:template match="l">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'l'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="lg">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'lg'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="sp">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'sp'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="speaker">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'speaker'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="stage">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'stage'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 5 Page and Line Numbers

-->

<!--

    In this implementation, default template rules will be used 
    to process the following tags:

        <pb>
        <lb>
        <milestone>

-->


<!--

    [TEI Lite] 6.1 Changes of Typeface, etc.

-->

  <xsl:template match="hi">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'hi'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="emph">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'emph'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="foreign">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'foreign'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="mentioned">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'mentioned'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="term">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'term'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="title">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'title'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 6.2 Quotations and Related Features

-->

<!--

    NOTE: Only a simple in-line formatting model is currently 
          implemented for quotations.

-->

  <xsl:template match="q">
    <xsl:call-template name="inline-quoted">
      <xsl:with-param name="class" select="'q'"/>
      <xsl:with-param name="before" select="$ldquo"/>
      <xsl:with-param name="after" select="$rdquo"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="mentioned">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'mentioned'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="soCalled">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'soCalled'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="gloss">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'gloss'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 7 Notes

-->

<!--

    NOTE: Only a simple interline formatting model is currently
          implemented for notes (i.e., the "place" attribute
          is not supported).

-->

  <xsl:template match="note">
    <xsl:call-template name="block-quoted">
      <xsl:with-param name="class" select="'note'"/>
      <xsl:with-param name="before" select="$note-label"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 8.1 Simple Cross References

-->

  <xsl:template match="ref[@target]">
    <A HREF="#{@target}">
      <xsl:call-template name="inline">
        <xsl:with-param name="class" select="'ref'"/>
      </xsl:call-template>
    </A>
  </xsl:template>

  <xsl:template match="ptr[@target]">
    <A HREF="#{@target}">
      <xsl:call-template name="inline-literal">
        <xsl:with-param name="class" select="'ptr'"/>
        <xsl:with-param name="content" select="$ptr-label"/>
      </xsl:call-template>
    </A>
  </xsl:template>

  <xsl:template match="anchor[@id]">
    <A NAME="{@id}"/>
  </xsl:template>

<!--

    See section 16.2 for template rule for the "seg" element.

-->


<!--

    [TEI Lite] 8.2 Extended Pointers

-->

<!--

    NOTE: In this release, the "doc" attribute is expected to contain
          an URL (probably with the fragment identifier). 
          The attributes "from" and "to" are not supported.

-->

  <xsl:template match="xref[@doc]">
    <A HREF="{@doc}">
      <xsl:call-template name="inline">
        <xsl:with-param name="class" select="'xref'"/>
      </xsl:call-template>
    </A>
  </xsl:template>

  <xsl:template match="xptr[@doc]">
    <A HREF="{@doc}">
      <xsl:call-template name="inline-literal">
        <xsl:with-param name="class" select="'xptr'"/>
        <xsl:with-param name="content" select="$xptr-label"/>
      </xsl:call-template>
    </A>
  </xsl:template>


<!--

    [TEI Lite] 8.3 Editorial interventions

-->

  <xsl:template match="corr">
    <xsl:choose>
      <xsl:when test="$original and @sic">
        <xsl:call-template name="inline-literal">
          <xsl:with-param name="class" select="'corr'"/>
          <xsl:with-param name="content" select="@sic"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="inline">
          <xsl:with-param name="class" select="'corr'"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="sic">
    <xsl:choose>
      <xsl:when test="not($original) and @corr">
        <xsl:call-template name="inline-literal">
          <xsl:with-param name="class" select="'sic'"/>
          <xsl:with-param name="content" select="@corr"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="inline-quoted">
          <xsl:with-param name="class" select="'sic'"/>
          <xsl:with-param name="after" select="$sic-after"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="orig">
    <xsl:choose>
      <xsl:when test="not($original) and @reg">
        <xsl:call-template name="inline-literal">
          <xsl:with-param name="class" select="'orig'"/>
          <xsl:with-param name="content" select="@reg"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="inline">
          <xsl:with-param name="class" select="'orig'"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="reg">
    <xsl:choose>
      <xsl:when test="$original and @orig">
        <xsl:call-template name="inline-literal">
          <xsl:with-param name="class" select="'reg'"/>
          <xsl:with-param name="content" select="@orig"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="inline">
          <xsl:with-param name="class" select="'reg'"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


<!--

    [TEI Lite] 10 Omissions, Deletions and Additions

-->

  <xsl:template match="add">
    <xsl:call-template name="inline-quoted">
      <xsl:with-param name="class" select="'add'"/>
      <xsl:with-param name="before" select="$add-before"/>
      <xsl:with-param name="after" select="$add-after"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="gap">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'gap'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="del">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'del'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="unclear">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'unclear'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 11.1 Names and Referring Strings

-->

  <xsl:template match="rs">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'rs'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="name">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'name'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 11.2 Dates and Times

-->

  <xsl:template match="date">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'date'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="time">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'time'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 11.3 Numbers

-->

  <xsl:template match="num">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'num'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 11.4 Abbreviations and their Expansion

-->

  <xsl:template match="abbr">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'abbr'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 11.5 Addresses

-->

  <xsl:template match="address">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'address'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="addrLine">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'addrLine'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 12 Lists

-->

<!--

    NOTE: In this implementation, bulleting and numbering is left
          to the user agent. The attribute "n" on "item" elements
          is not supported. Custom CSS styles can be defined for
          generated UL, OL and DL elements, but in case of nested
          lists the same style will be applied to all elements of
          the same type. Implementing custom values for "rend"
          attribute may provide additional customization opportunities.

-->

  <xsl:template match="list">
    <DIV CLASS="list">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates select="head"/>
      <UL CLASS="list">
        <xsl:apply-templates select="item" mode="bulleted"/>
      </UL>
    </DIV>
  </xsl:template>

  <xsl:template match="list[@rend='disc']">
    <DIV CLASS="list">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates select="head"/>
      <UL CLASS="list-disc">
        <xsl:apply-templates select="item" mode="bulleted"/>
      </UL>
    </DIV>
  </xsl:template>

  <xsl:template match="list[@rend='circle']">
    <DIV CLASS="list">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates select="head"/>
      <UL CLASS="list-circle">
        <xsl:apply-templates select="item" mode="bulleted"/>
      </UL>
    </DIV>
  </xsl:template>

  <xsl:template match="list[@rend='square']">
    <DIV CLASS="list">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates select="head"/>
      <UL CLASS="list-square">
        <xsl:apply-templates select="item" mode="bulleted"/>
      </UL>
    </DIV>
  </xsl:template>

  <xsl:template 
        match="list[(not(@type) and item[1][@n]) or @type='ordered']"
        priority="1">
    <DIV CLASS="list">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates select="head"/>
      <OL CLASS="list">
        <xsl:apply-templates select="item" mode="ordered"/>
      </OL>
    </DIV>
  </xsl:template>

  <xsl:template 
        match="list[(not(@type) and label) or @type='gloss']"
        priority="2">
    <DIV CLASS="list">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates select="head"/>
      <DL CLASS="list">
        <xsl:apply-templates select="label|item" mode="gloss"/>
      </DL>
    </DIV>
  </xsl:template>

  <xsl:template match="list/head">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'list-head'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="item" mode="bulleted">
    <LI CLASS="item">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </LI>
  </xsl:template>

  <xsl:template match="item" mode="ordered">
    <LI CLASS="item">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </LI>
  </xsl:template>

  <xsl:template match="label" mode="gloss">
    <DT CLASS="label">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </DT>
  </xsl:template>

  <xsl:template match="item" mode="gloss">
    <DD CLASS="item">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </DD>
  </xsl:template>


<!--

    [TEI Lite] 13 Bibliographic Citations

-->

  <xsl:template match="listBibl">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'listBibl'"/>
    </xsl:call-template>
  </xsl:template>

<!--

    NOTE: In this release, "bibl" is always formatted as 
          inline element when it is not child of "listBibl".

-->

  <xsl:template match="listBibl/bibl">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'bibl'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="bibl">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'bibl'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="author">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'author'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="biblScope">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'biblScope'"/>
    </xsl:call-template>
  </xsl:template>

<!--

    The template rule for "date" is already defined (see section 11.2)

-->

  <xsl:template match="editor">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'editor'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="imprint">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'imprint'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="publisher">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'publisher'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="pubPlace">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'pubPlace'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="series">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'series'"/>
    </xsl:call-template>
  </xsl:template>

<!--

    The template rule for "title" is already defined (see section 6.1)

-->


<!--

    [TEI Lite] 14 Tables

-->

<!--

    NOTE: More efficient implementation could be provided using
          modes, but this is a good example of complex matching
          patterns and priorities.

-->

  <xsl:template match="table">
    <TABLE CLASS="table">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates select="row"/>
    </TABLE>
  </xsl:template>

  <xsl:template match="table/row">
    <TR CLASS="row">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates select="cell"/>
    </TR>
  </xsl:template>

  <xsl:template match="table/row/cell[@role='label']" priority="2">
    <TH CLASS="cell">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="cell-span"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </TH>
  </xsl:template>

  <xsl:template match="table/row/cell[@role='data']" priority="2">
    <TD CLASS="cell">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="cell-span"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </TD>
  </xsl:template>

  <xsl:template match="table/row[@role='label']/cell" priority="1">
    <TH CLASS="cell">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="cell-span"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </TH>
  </xsl:template>

  <xsl:template match="table/row/cell">
    <TD CLASS="cell">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="cell-span"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </TD>
  </xsl:template>


<!--

    [TEI Lite] 15 Figures and Graphics

-->

<!--

    NOTE: Numbering figures is currently not supported.

-->

  <xsl:template match="figure[@entity]">
    <DIV CLASS="figure">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <IMG CLASS="figure" SRC="{unparsed-entity-uri(@entity)}"/>
      <xsl:apply-templates select="head"/>
    </DIV>
  </xsl:template>

  <xsl:template match="figure">
    <DIV CLASS="figure">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:copy-of select="$figure-label"/>
      <xsl:apply-templates select="head"/>
    </DIV>
  </xsl:template>

  <xsl:template match="figure/head">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'figure-head'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 16.1 Orthographic Sentences

-->

<!--

    In this implementation, default template rules will be used 
    to process the following tags:

        <s>

-->


<!--

    [TEI Lite] 16.2 General-Purpose Interpretation Elements

-->

<!--

    In this implementation, default template rules will be used 
    to process the following tags:

        <interp>
        <interpGrp>

-->

<!--

    In this release, "seg" is used to mark all fragments that have
    the special semantics not addressed directly by TEI Lite.
    The attribute "type" is used to describe the fragment meaning
    and formatting options. The following set of template rules
    MAY BE CUSTOMIZED in order to implement application-specific
    values of "type" attribute.

-->

  <xsl:template match="seg[@type='formal']">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'seg-formal'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="seg[@type='formal-line'][@part='M' or @part='F']"
                priority="2">
    <xsl:call-template name="block-quoted">
      <xsl:with-param name="class" select="'seg-formal-line'"/>
      <xsl:with-param name="before" select="$continued-line"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="seg[@type='formal-line']"
                priority="1">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'seg-formal-line'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="seg[@type='namespace']">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'seg-namespace'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="seg[@type='prefix']">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'seg-prefix'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="seg[@type='qname']">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'seg-qname'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="seg[@type='code']">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'seg-code'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="seg[@type='notation']">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'seg-notation'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="seg[@type='meta']">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'seg-meta'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="seg[@type='ident']">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'seg-ident'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="seg[@type='value']">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'seg-value'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="seg">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'seg'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 17.1 Additional elements for technical documents

-->

<!--

    NOTE: The PRE element is needed since some older browsers do not 
          understand "white-space: pre" style declaration).

-->

  <xsl:template match="eg">
    <PRE CLASS="eg">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </PRE>
  </xsl:template>

  <xsl:template match="code">
    <PRE CLASS="code">
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </PRE>
  </xsl:template>

  <xsl:template match="ident">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'ident'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="gi">
    <xsl:call-template name="inline-quoted">
      <xsl:with-param name="class" select="'gi'"/>
      <xsl:with-param name="before" select="'&lt;'"/>
      <xsl:with-param name="after" select="'&gt;'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="kw">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'kw'"/>
    </xsl:call-template>
  </xsl:template>

<!--

    No proper support for formulae ...

-->

  <xsl:template match="formula">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'formula'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 17.2 Generated Divisions

-->

<!--

    NOTE: The element <divGen> is not yet supported

-->

  <xsl:template match="divGen"/>


<!--

    [TEI Lite] 17.3 Index Generation

-->

<!--

    NOTE: The element <index> is not yet supported

-->

  <xsl:template match="index"/>


<!--

    [TEI Lite] 19.1.1 Title Page

-->

  <xsl:template match="titlePage">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'titlePage'"/>
    </xsl:call-template>
    <HR CLASS="titlePage"/>
  </xsl:template>

  <xsl:template match="docTitle">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'docTitle'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="titlePart">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'titlePart'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="byline">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'byline'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="docAuthor">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'docAuthor'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="byline/docAuthor">
    <xsl:call-template name="inline">
      <xsl:with-param name="class" select="'docAuthor'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="docDate">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'docDate'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="docEdition">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'docEdition'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="docImprint">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'docImprint'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="epigraph">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'epigraph'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    [TEI Lite] 19.1.2 Prefatory Matter

-->

  <xsl:template match="salute">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'salute'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="signed">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'signed'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="dateline">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'dateline'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="argument">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'argument'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="cit">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'cit'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="opener">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'opener'"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="closer">
    <xsl:call-template name="block">
      <xsl:with-param name="class" select="'closer'"/>
    </xsl:call-template>
  </xsl:template>


<!--

    Formatting Utilities

-->

  <xsl:template name="block">
    <xsl:param name="class"/>
    <DIV>
      <xsl:if test="$class">
        <xsl:attribute name="CLASS">
          <xsl:value-of select="$class"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </DIV>
  </xsl:template>

  <xsl:template name="block-quoted">
    <xsl:param name="class"/>
    <xsl:param name="before"/>
    <xsl:param name="after"/>
    <DIV>
      <xsl:if test="$class">
        <xsl:attribute name="CLASS">
          <xsl:value-of select="$class"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:copy-of select="$before"/>
      <xsl:apply-templates/>
      <xsl:copy-of select="$after"/>
    </DIV>
  </xsl:template>

  <xsl:template name="inline">
    <xsl:param name="class"/>
    <SPAN>
      <xsl:if test="$class">
        <xsl:attribute name="CLASS">
          <xsl:value-of select="$class"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </SPAN>
  </xsl:template>

  <xsl:template name="inline-quoted">
    <xsl:param name="class"/>
    <xsl:param name="before"/>
    <xsl:param name="after"/>
    <SPAN>
      <xsl:if test="$class">
        <xsl:attribute name="CLASS">
          <xsl:value-of select="$class"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:copy-of select="$before"/>
      <xsl:apply-templates/>
      <xsl:copy-of select="$after"/>
    </SPAN>
  </xsl:template>

  <xsl:template name="inline-literal">
    <xsl:param name="class"/>
    <xsl:param name="content"/>
    <SPAN>
      <xsl:if test="$class">
        <xsl:attribute name="CLASS">
          <xsl:value-of select="$class"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:call-template name="common-attributes"/>
      <xsl:call-template name="anchor"/>
      <xsl:copy-of select="$content"/>
    </SPAN>
  </xsl:template>

  <xsl:template name="common-attributes">
    <xsl:if test="@id">
      <xsl:attribute name="ID">
        <xsl:value-of select="@id"/>
      </xsl:attribute>
    </xsl:if>
    <xsl:if test="@rend">
      <xsl:call-template name="rend-style"/>
    </xsl:if>
  </xsl:template>

  <xsl:template name="anchor">
    <xsl:if test="@id and key('ref', @id)">
      <A NAME="{@id}"/>
    </xsl:if>
  </xsl:template>

  <xsl:template name="div-number">
    <xsl:choose>
      <xsl:when test="ancestor::body">
        <xsl:number level="multiple"
                    count="div|div1|div2|div3|div4|div5|div6|div7"
                    format="1.1 "/>
      </xsl:when>
      <xsl:when test="ancestor::back">
        <xsl:number level="multiple"
                    count="div|div1|div2|div3|div4|div5|div6|div7"
                    format="A.1 "/>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="cell-span">
    <xsl:if test="@cols">
      <xsl:attribute name="COLSPAN">
        <xsl:value-of select="@cols"/>
      </xsl:attribute>
    </xsl:if>
    <xsl:if test="@rows">
      <xsl:attribute name="ROWSPAN">
        <xsl:value-of select="@rows"/>
      </xsl:attribute>
    </xsl:if>
  </xsl:template>


  <xsl:template name="style">
<!--

    MAY BE CUSTOMIZED: Modify the following CSS style definitions
                      to achieve the custom formatting

-->
    <STYLE>
      H1 { font-size: 14pt }
      H2 { font-size: 12pt }
      H3 { font-size: 12pt }
      H4 { font-size: 12pt }
      H5 { font-size: 12pt }
      H6 { font-size: 12pt }
      DIV.back-head { font-size: 18pt; font-weight: bold; 
                 margin-top: 1em; margin-bottom: 1em }
      DIV.head { font-size: 12pt; font-weight: bold; 
                 margin-top: 1em; margin-bottom: 1em }
      DIV.trailer { margin-top: 1em; margin-bottom: 1em }
      DIV.lg { margin-top: 1em; margin-bottom: 1em }
      DIV.sp { margin-top: 1em; margin-bottom: 1em }
      DIV.speaker { margin-top: 1em; margin-bottom: 1em }
      DIV.stage { margin-top: 1em; margin-bottom: 1em }
      DIV.note { margin-top: 1em; margin-bottom: 1em }
      DIV.address { margin-top: 1em; margin-bottom: 1em }
      DIV.list-head { margin-top: 1em; margin-bottom: 1em }
      DIV.seg-formal { margin-top: 1em; margin-bottom: 1em }
      DIV.seg-formal-line { font-family: monospace; font-size: smaller }
      DIV.listBibl { margin-top: 1em; margin-bottom: 1em }
      DIV.bibl { margin-top: 1em; margin-bottom: 1em }
      DIV.figure-head { margin-top: 1em; margin-bottom: 1em }
      DIV.docTitle { font-size: 24pt; font-weight: bold;
                     margin-top: 1em; margin-bottom: 1em }
      DIV.titlePart { font-size: 24pt; font-weight: bold }
      DIV.byline { margin-top: 2em; margin-bottom: 1em }
      DIV.docAuthor { font-size: 18pt; font-weight: bold;
                      margin-top: 1em; margin-bottom: 1em }
      DIV.docDate { font-size: 18pt; font-weight: bold;
                    margin-top: 1em; margin-bottom: 1em }
      DIV.docEdition { font-weight: bold;
                       margin-top: 1em; margin-bottom: 1em }
      DIV.docImprint { font-weight: bold;
                       margin-top: 1em; margin-bottom: 1em }
      DIV.epigraph { margin-top: 1em; margin-bottom: 1em }
      DIV.salute { margin-top: 1em; margin-bottom: 1em }
      DIV.signed { margin-top: 1em; margin-bottom: 1em }
      DIV.dateline { margin-top: 1em; margin-bottom: 1em }
      DIV.argument { margin-top: 1em; margin-bottom: 1em }
      DIV.cit { margin-top: 1em; margin-bottom: 1em }
      DIV.opener { margin-top: 1em; margin-bottom: 1em }
      DIV.closer { margin-top: 1em; margin-bottom: 1em }
      UL { list-style-type: none }
      UL.list-disc { list-style-type: disc }
      UL.list-circle { list-style-type: circle }
      UL.list-square { list-style-type: square }
      SPAN.emph { font-style: italic }
      SPAN.term { font-weight: bold }
      SPAN.note-label { font-weight: bold }
      SPAN.seg-namespace { font-family: monospace; font-size: smaller }
      SPAN.seg-prefix { font-family: monospace; font-size: smaller }
      SPAN.seg-qname { font-family: monospace; font-size: smaller }
      SPAN.seg-code { font-family: monospace; font-size: smaller; font-weight: bold }
      SPAN.seg-notation { font-family: monospace; font-size: smaller }
      SPAN.seg-meta { font-family: monospace; font-size: smaller; font-style: italic }
      SPAN.seg-ident { font-family: monospace; font-size: smaller }
      SPAN.seg-value { font-family: monospace; font-size: smaller }
      SPAN.ident { font-family: monospace; font-size: smaller }
      SPAN.gi { font-family: monospace; font-size: smaller }
      SPAN.kw { font-family: monospace; font-size: smaller }
    </STYLE>
  </xsl:template>

  <xsl:template name="rend-style">
    <xsl:choose>
      <xsl:when test="@rend='monospace'">
        <xsl:attribute name="STYLE">
          <xsl:text>font-family: monospace; font-size: smaller;</xsl:text>
        </xsl:attribute>
      </xsl:when>
      <xsl:when test="@rend='italic'">
        <xsl:attribute name="STYLE">
          <xsl:text>font-style: italic</xsl:text>
        </xsl:attribute>
      </xsl:when>
      <xsl:when test="@rend='oblique'">
        <xsl:attribute name="STYLE">
          <xsl:text>font-style: oblique</xsl:text>
        </xsl:attribute>
      </xsl:when>
      <xsl:when test="@rend='bold'">
        <xsl:attribute name="STYLE">
          <xsl:text>font-weight: bold</xsl:text>
        </xsl:attribute>
      </xsl:when>
      <xsl:when test="@rend='small'">
        <xsl:attribute name="STYLE">
          <xsl:text>font-size: small</xsl:text>
        </xsl:attribute>
      </xsl:when>
      <xsl:when test="@rend='large'">
        <xsl:attribute name="STYLE">
          <xsl:text>font-size: large</xsl:text>
        </xsl:attribute>
      </xsl:when>
<!--

    MAY BE CUSTOMIZED: Add CSS styles for custom "rend" values here

-->
    </xsl:choose>
  </xsl:template>


</xsl:stylesheet>


